import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  area,
  curveBasis
  annotationCalloutCircle
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Beer Consumption Per Person in U.S.';
  
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  const yValueW = d => d.Wine;
  const circleRadius = 4;
  const yAxisLabelW = 'Wine';
  
  const yValueB = d => d.Beer;
  const yAxisLabelB = 'Beer';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 105 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);
  
  const yScaleW = scaleLinear()
    .domain(extent(data, yValueW))
    .range([innerHeight, 0])
    .nice();
  
  const yScaleB = scaleLinear()
    .domain(extent(data, yValueB))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
    .ticks(10)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxisW = axisLeft(yScaleW)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
   const yAxisB = axisright(yScaleB)
    .tickSize(innerWidth)
    .tickPadding(10);
  
  const yAxisGW = g.append('g').call(yAxisW);
  yAxisGW.selectAll('.domain').remove();
  
  yAxisGW.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabelW);
  
  const yAxisGB = g.append('g').call(yAxisB);
  yAxisGB.selectAll('.domain').remove();
  
  yAxisGB.append('text')
      .attr('class', 'axis-label')
      .attr('y', 88)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabelB);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  const areaGeneratorW = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScaleW(yValueW(d)))
    .curve(curveBasis);
  
  const areaGeneratorB = area()
    .x(d => xScale(xValue(d)))
    .y0(innerHeight)
    .y1(d => yScaleB(yValueB(d)))
    .curve(curveBasis);
  
  g.append('path')
      .attr('class', 'line-path-W')
      .attr('d', areaGeneratorW(data));
  
  g.append('path')
      .attr('class', 'line-path-B')
      .attr('d', areaGeneratorB(data));
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('data.csv')
  .then(data => {
    data.forEach(d => {
      d.Year = new Date(d.Year);
      d.Spirits = +d.Spirits;
      d.Beer = +d.Beer;
      d.Wine = +d.Wine;
    });
    render(data);
  });